/* $Header: /cvs/gnome/gIDE/src/gide.h,v 1.6 2000/04/22 17:23:01 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 Steffen Kern
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GIDE_H
#define GIDE_H

#include <gnome.h>
#include "gI_window.h"
#include "gI_document.h"
#include "structs.h"

/* Widgets: Main-Window & Box */
extern GideWindow *main_window;

/* Configuration */
extern gI_config *cfg;

extern char gide_path[MAXLEN];
extern char tools_path[MAXLEN];
extern char prj_path[MAXLEN];

void set_cfg_defaults(void);

#endif

